==> uni_pytorch-1.10.0-py3-none-any.whl: uni/pytorch/onnx_parser/nnir_node_factory/dummy_factories.py <==
# -------------------------------------------------------------------------------
# (c) Copyright 2022 Sony Semiconductor Israel, Ltd. All rights reserved.
#
#      This software, in source or object form (the "Software"), is the
#      property of Sony Semiconductor Israel Ltd. (the "Company") and/or its
#      licensors, which have all right, title and interest therein, You
#      may use the Software only in accordance with the terms of written
#      license agreement between you and the Company (the "License").
#      Except as expressly stated in the License, the Company grants no
#      licenses by implication, estoppel, or otherwise. If you are not
#      aware of or do not agree to the License terms, you may not use,
#      copy or modify the Software. You may use the source code of the
#      Software only for your internal purposes and may not distribute the
#      source code of the Software, any part thereof, or any derivative work
#      thereof, to any third party, except pursuant to the Company's prior
#      written consent.
#      The Software is the confidential information of the Company.
# -------------------------------------------------------------------------------
"""
Created on 10/19/22

@author: irenab
"""
from .base_factory import OnnxFactoryBase, validate_onnx
from uni.common.core.nnir_graph.nnir_nodes import DummyInput, DummyOutput


class OnnxDummyInputToNnirNode(OnnxFactoryBase):

    @classmethod
    @validate_onnx(num_inputs=0, num_outputs=1, attrs=[])
    def from_onnx(cls, onnx_node, **kwargs) -> DummyInput:
        return DummyInput(onnx_node.name)


class OnnxDummyOutputToNnirNode(OnnxFactoryBase):

    @classmethod
    @validate_onnx(num_inputs=None, num_outputs=0, attrs=[])
    def from_onnx(cls, onnx_node, **kwargs) -> DummyOutput:
        return DummyOutput(onnx_node.name)

==> uni_pytorch-3.16.1-py3-none-any.whl: uni/pytorch/onnx_parser/nnir_node_factory/dummy_factories.py <==
# -------------------------------------------------------------------------------
# (c) Copyright 2022 Sony Semiconductor Israel, Ltd. All rights reserved.
#
#      This software, in source or object form (the "Software"), is the
#      property of Sony Semiconductor Israel Ltd. (the "Company") and/or its
#      licensors, which have all right, title and interest therein, You
#      may use the Software only in accordance with the terms of written
#      license agreement between you and the Company (the "License").
#      Except as expressly stated in the License, the Company grants no
#      licenses by implication, estoppel, or otherwise. If you are not
#      aware of or do not agree to the License terms, you may not use,
#      copy or modify the Software. You may use the source code of the
#      Software only for your internal purposes and may not distribute the
#      source code of the Software, any part thereof, or any derivative work
#      thereof, to any third party, except pursuant to the Company's prior
#      written consent.
#      The Software is the confidential information of the Company.
# -------------------------------------------------------------------------------
"""
Created on 10/19/22

@author: irenab
"""
from uni.pytorch.onnx_parser.nnir_node_factory.base_factory import OnnxFactoryBase, validate_onnx
from uni.common.core.nnir_graph.nnir_nodes import DummyInput, DummyOutput


class OnnxDummyInputToNnirNode(OnnxFactoryBase):

    @classmethod
    @validate_onnx(num_inputs=0, num_outputs=1, attrs=[])
    def from_onnx(cls, onnx_node, **kwargs) -> DummyInput:
        return DummyInput(onnx_node.name)


class OnnxDummyOutputToNnirNode(OnnxFactoryBase):

    @classmethod
    @validate_onnx(num_inputs=None, num_outputs=0, attrs=[])
    def from_onnx(cls, onnx_node, **kwargs) -> DummyOutput:
        return DummyOutput(onnx_node.name)
